This function estimates the parameters of a VAR model
using the dynr package.
Usage
FitVARDynr(
model,
conf_level = 0.95,
optimization_flag = TRUE,
hessian_flag = FALSE,
verbose = FALSE,
weight_flag = FALSE,
debug_flag = FALSE,
perturb_flag = FALSE
)Arguments
- model
Ouput of
ModelVARP1Dynr()orModelVARP2Dynr().- conf_level
a cumulative proportion indicating the level of desired confidence intervals for the final parameter estimates (default is .95)
- optimization_flag
a flag (TRUE/FALSE) indicating whether optimization is to be done.
- hessian_flag
a flag (TRUE/FALSE) indicating whether the Hessian matrix is to be calculated.
- verbose
a flag (TRUE/FALSE) indicating whether more detailed intermediate output during the estimation process should be printed
- weight_flag
a flag (TRUE/FALSE) indicating whether the negative log likelihood function should be weighted by the length of the time series for each individual
- debug_flag
a flag (TRUE/FALSE) indicating whether users want additional dynr output that can be used for diagnostic purposes
- perturb_flag
a flag (TRUE/FLASE) indicating whether to perturb the latent states during estimation. Only useful for ensemble forecasting.
See also
Other Fitting Autoregressive Model Functions:
FitMLVARDynr(),
FitMLVARMplus(),
FitVARLassoSearch(),
FitVARLasso(),
FitVARMplus(),
FitVAROLS(),
LambdaSeq(),
ModelVARP1Dynr(),
ModelVARP2Dynr(),
OrigScale(),
PBootVARExoLasso(),
PBootVARExoOLS(),
PBootVARLasso(),
PBootVAROLS(),
RBootVARExoLasso(),
RBootVARExoOLS(),
RBootVARLasso(),
RBootVAROLS(),
SearchVARLasso(),
StdMat()
Examples
if (FALSE) {
FitVARDynr(model = ModelVARP1Dynr(data = dat_p1))
FitVARDynr(model = ModelVARP2Dynr(data = dat_p2))
}