Parametric Bootstrap for the Vector Autoregressive Model with Exogenous Variables Using Ordinary Least Squares
Source:R/RcppExports.R
PBootVARExoOLS.RdParametric Bootstrap for the Vector Autoregressive Model with Exogenous Variables Using Ordinary Least Squares
Arguments
- data
Numeric matrix. The time series data with dimensions
tbyk, wheretis the number of observations andkis the number of variables.- exo_mat
Numeric matrix. Matrix of exogenous variables with dimensions
t + burn_inbym. If the number of rows is equal tot, setburn_in = 0.- p
Integer. The order of the VAR model (number of lags).
- B
Integer. Number of bootstrap samples to generate.
- burn_in
Integer. Number of burn-in observations to exclude before returning the results in the simulation step.
Value
List with the following elements:
est: Numeric matrix. Original OLS estimate of the coefficient matrix.
boot: Numeric matrix. Matrix of vectorized bootstrap estimates of the coefficient matrix.
See also
Other Fitting Autoregressive Model Functions:
FitMLVARDynr(),
FitMLVARMplus(),
FitVARDynr(),
FitVARLassoSearch(),
FitVARLasso(),
FitVARMplus(),
FitVAROLS(),
LambdaSeq(),
ModelVARP1Dynr(),
ModelVARP2Dynr(),
OrigScale(),
PBootVARExoLasso(),
PBootVARLasso(),
PBootVAROLS(),
RBootVARExoLasso(),
RBootVARExoOLS(),
RBootVARLasso(),
RBootVAROLS(),
SearchVARLasso(),
StdMat()
Examples
data <- dat_p2_exo$data
exo_mat <- dat_p2_exo$exo_mat
pb <- PBootVARExoOLS(
data = data,
exo_mat = exo_mat,
p = 2,
B = 5,
burn_in = 0
)
str(pb)
#> List of 2
#> $ est : num [1:3, 1:10] 1.1645 0.6747 1.1333 0.358 0.0194 ...
#> $ boot: num [1:5, 1:30] 1.28 0.86 1.3 1.39 1.14 ...