Parametric Bootstrap for the Vector Autoregressive Model Using Ordinary Least Squares
Source:R/RcppExports.R
PBootVAROLS.RdParametric Bootstrap for the Vector Autoregressive Model Using Ordinary Least Squares
Arguments
- data
Numeric matrix. The time series data with dimensions
tbyk, wheretis the number of observations andkis the number of variables.- p
Integer. The order of the VAR model (number of lags).
- B
Integer. Number of bootstrap samples to generate.
- burn_in
Integer. Number of burn-in observations to exclude before returning the results in the simulation step.
Value
List with the following elements:
est: Numeric matrix. Original OLS estimate of the coefficient matrix.
boot: Numeric matrix. Matrix of vectorized bootstrap estimates of the coefficient matrix.
See also
Other Fitting Autoregressive Model Functions:
FitMLVARDynr(),
FitMLVARMplus(),
FitVARDynr(),
FitVARLassoSearch(),
FitVARLasso(),
FitVARMplus(),
FitVAROLS(),
LambdaSeq(),
ModelVARP1Dynr(),
ModelVARP2Dynr(),
OrigScale(),
PBootVARExoLasso(),
PBootVARExoOLS(),
PBootVARLasso(),
RBootVARExoLasso(),
RBootVARExoOLS(),
RBootVARLasso(),
RBootVAROLS(),
SearchVARLasso(),
StdMat()
Examples
pb <- PBootVAROLS(data = dat_p2, p = 2, B = 5, burn_in = 20)
str(pb)
#> List of 2
#> $ est : num [1:3, 1:7] 0.79 1.0002 1.0667 0.3684 0.0133 ...
#> $ boot: num [1:5, 1:21] 0.809 0.521 0.692 0.645 0.855 ...